@@ -12,7 +12,7 @@ from ngsderive.commands import (
     strandedness,
     encoding,
     junction_annotation,
-    junction_saturation,
+    endedness,
 )
 
 logger = logging.getLogger("ngsderive")
@@ -54,7 +54,6 @@ def get_args():
         action="store_true",
         help="Enable INFO log level.",
     )
-    common.add_argument("--version", action="version", version="%(prog)s 1.0.0")
 
     readlen = subparsers.add_parser(
         "readlen", parents=[common], formatter_class=SaneFormatter
@@ -68,10 +67,10 @@ def get_args():
     )
     readlen.add_argument(
         "-n",
-        "--n-samples",
+        "--n-reads",
         type=int,
-        help="How many reads to sample. Any n < 1 to parse whole file.",
-        default=1000000,
+        help="How many reads to analyze from the start of the file. Any n < 1 to parse whole file.",
+        default=-1,
     )
 
     instrument = subparsers.add_parser(
@@ -79,9 +78,9 @@ def get_args():
     )
     instrument.add_argument(
         "-n",
-        "--n-samples",
+        "--n-reads",
         type=int,
-        help="How many reads to sample. Any n < 1 to parse whole file.",
+        help="How many reads to analyze from the start of the file. Any n < 1 to parse whole file.",
         default=10000,
     )
 
@@ -96,7 +95,7 @@ def get_args():
         type=int,
         default=3,
         help="When inconclusive, the test will repeat until this many tries have been reached. "
-             "Evidence of previous attempts is saved and reused, leading to a larger sample size with multiple attempts.",
+        + "Evidence of previous attempts is saved and reused, leading to a larger sample size with multiple attempts.",
     )
     strandedness.add_argument(
         "--max-iterations-per-try",
@@ -150,9 +149,9 @@ def get_args():
     )
     encoding.add_argument(
         "-n",
-        "--n-samples",
+        "--n-reads",
         type=int,
-        help="How many reads to sample. Any n < 1 to parse whole file.",
+        help="How many reads to analyze from the start of the file. Any n < 1 to parse whole file.",
         default=1000000,
     )
 
@@ -208,65 +207,62 @@ def get_args():
         action="store_true",
         default=False,
         help="For the summary report, consider all events on unannotated reference sequences `complete_novel`. "
-             "Default is to exclude them from the summary. "
-             "Either way, they will be annotated as `unannotated_reference` in the junctions file.",
+        + "Default is to exclude them from the summary. "
+        + "Either way, they will be annotated as `unannotated_reference` in the junctions file.",
     )
 
-    junction_saturation = subparsers.add_parser(
-        "junction-saturation", parents=[common], formatter_class=SaneFormatter
+    endedness = subparsers.add_parser(
+        "endedness", parents=[common], formatter_class=SaneFormatter
     )
-    junction_saturation.add_argument(
-        "-g", "--gene-model", help="Gene model as a GFF/GTF file.", required=True
-    )
-    junction_saturation.add_argument(
-        "-s",
-        "--sample-start",
+    endedness.add_argument(
+        "-n",
+        "--n-reads",
         type=int,
-        help="Percentage to begin sampling.",
-        default=5,
+        help="How many reads to analyze from the start of the file. Any n < 1 to parse whole file.",
+        default=-1,
     )
-    junction_saturation.add_argument(
+    endedness.add_argument(
         "-p",
-        "--sample-step",
-        type=int,
-        help="Percentage to step between sample-start and sample-end.",
-        default=5,
+        "--paired-deviance",
+        type=float,
+        help="Distance from 0.5 split between number of f+l- reads and f-l+ reads "
+        + "allowed to be called 'Paired-End'. Default of `0.0` only appropriate "
+        + "if the whole file is being processed.",
+        default=0.0,
     )
-    junction_saturation.add_argument(
-        "-e",
-        "--sample-end",
-        type=int,
-        help="Percentage to stop sampling.",
-        default=100,
+    endedness.add_argument(
+        "--lenient",
+        action="store_true",
+        default=False,
+        help="Return a zero exit code on unknown results",
     )
-    junction_saturation.add_argument(
-        "-i",
-        "--min-intron",
-        type=int,
-        help="Minimum size of intron to be considered a splice.",
-        default=50,
+    endedness.add_argument(
+        "-r",
+        "--calc-rpt",
+        action="store_true",
+        default=False,
+        help="Calculate and output Reads-Per-Template. This will produce a more "
+        + "sophisticated estimate for endedness, but uses substantially more memory "
+        + "(can reach up to 60-70%% of BAM size in memory consumption).",
     )
-    junction_saturation.add_argument(
-        "-q",
-        "--min-mapq",
-        type=int,
-        help="Minimum MAPQ to consider for supporting reads.",
-        default=30,
+    endedness.add_argument(
+        "--round-rpt",
+        action="store_true",
+        default=False,
+        help="Round RPT to the nearest INT before comparing to expected values. "
+        + "Appropriate if using `-n` > 0.",
     )
-    junction_saturation.add_argument(
-        "-m",
-        "--min-reads",
-        type=int,
-        help="Filter any junctions that don't have at least `m` reads.",
-        default=2,
+    split_by_rg_parser = endedness.add_mutually_exclusive_group(required=False)
+    split_by_rg_parser.add_argument(
+        "--split-by-rg",
+        dest="split_by_rg",
+        action="store_true",
+        help="Contain one entry per read group.",
     )
-    junction_saturation.add_argument(
-        "-k",
-        "--fuzzy-junction-match-range",
-        type=int,
-        help="Consider found splices within `+-k` bases of a known splice event annotated.",
-        default=0,
+    split_by_rg_parser.add_argument(
+        "--no-split-by-rg", dest="split_by_rg", action="store_false"
     )
+    endedness.set_defaults(split_by_rg=False)
 
     args = parser.parse_args()
     if not args.subcommand:
@@ -328,21 +324,6 @@ def process_args(args):
     else:
         args.outfile = open(args.outfile, "w")
 
-    # check junction-saturation args
-    if args.subcommand == "junction-saturation":
-        if (
-            (not 0 <= args.sample_start and not args.sample_start <= 100)
-            or (not 0 <= args.sample_step and not args.sample_step <= 100)
-            or (not 0 <= args.sample_end and not args.sample_end <= 100)
-        ):
-            raise argparse.ArgumentError(
-                "--sample-start, --sample-step, and --sample-end must be percentages between 0 and 100 (inclusive)"
-            )
-        if args.sample_start > args.sample_end:
-            raise argparse.ArgumentError(
-                "--sample-start must be less than --sample-end"
-            )
-
 
 def run():
     args = get_args()
@@ -352,14 +333,14 @@ def run():
         readlen.main(
             args.ngsfiles,
             outfile=args.outfile,
-            n_samples=args.n_samples,
+            n_reads=args.n_reads,
             majority_vote_cutoff=args.majority_vote_cutoff,
         )
     if args.subcommand == "instrument":
         instrument.main(
             args.ngsfiles,
             outfile=args.outfile,
-            n_samples=args.n_samples,
+            n_reads=args.n_reads,
         )
     if args.subcommand == "strandedness":
         max_iters = args.max_iterations_per_try
@@ -374,13 +355,14 @@ def run():
             only_protein_coding_genes=args.only_protein_coding_genes,
             min_mapq=args.min_mapq,
             split_by_rg=args.split_by_rg,
+            max_tries=args.max_tries,
             max_iterations_per_try=max_iters,
         )
     if args.subcommand == "encoding":
         encoding.main(
             args.ngsfiles,
             outfile=args.outfile,
-            n_samples=args.n_samples,
+            n_reads=args.n_reads,
         )
     if args.subcommand == "junction-annotation":
         junction_annotation.main(
@@ -395,16 +377,14 @@ def run():
             junction_dir=args.junction_files_dir,
             disable_junction_files=args.disable_junction_files,
         )
-    if args.subcommand == "junction-saturation":
-        junction_saturation.main(
+    if args.subcommand == "endedness":
+        endedness.main(
             args.ngsfiles,
-            args.gene_model,
             outfile=args.outfile,
-            sample_start=args.sample_start,
-            sample_step=args.sample_step,
-            sample_end=args.sample_end,
-            min_intron=args.min_intron,
-            min_mapq=args.min_mapq,
-            min_reads=args.min_reads,
-            fuzzy_range=args.fuzzy_junction_match_range,
+            n_reads=args.n_reads,
+            paired_deviance=args.paired_deviance,
+            lenient=args.lenient,
+            calc_rpt=args.calc_rpt,
+            round_rpt=args.round_rpt,
+            split_by_rg=args.split_by_rg,
         )
