@@ -195,7 +195,7 @@ def resolve_instrument(
         )
 
 
-def main(ngsfiles, outfile=sys.stdout, n_samples=10000):
+def main(ngsfiles, outfile, n_reads):
     writer = csv.DictWriter(
         outfile,
         fieldnames=["File", "Instrument", "Confidence", "Basis"],
@@ -204,8 +204,8 @@ def main(ngsfiles, outfile=sys.stdout, n_samples=10000):
     writer.writeheader()
     outfile.flush()
 
-    if n_samples < 1:
-        n_samples = None
+    if n_reads < 1:
+        n_reads = None
 
     for ngsfilepath in ngsfiles:
         try:
@@ -227,22 +227,34 @@ def main(ngsfiles, outfile=sys.stdout, n_samples=10000):
         malformed_read_names = False
 
         # accumulate instrument and flowcell IDs
-        for read in itertools.islice(ngsfile, n_samples):
-            parts = read["query_name"].split(":")
-            if len(parts) != 7:  # not Illumina format
-                malformed_read_names = True
-                iid = parts[0]  # attempt to recover machine name
+        try:
+            for read in itertools.islice(ngsfile, n_reads):
+                parts = read["query_name"].split(":")
+                if len(parts) != 7:  # not Illumina format
+                    malformed_read_names = True
+                    iid = parts[0]  # attempt to recover machine name
+                    instruments.add(iid)
+                    for rg in ngsfile.handle.header.to_dict()["RG"]:
+                        if rg["ID"] == read["read_group"]:
+                            if "PU" in rg:
+                                flowcells.add(rg["PU"])
+                            if "PM" in rg:
+                                instruments.add(rg["PM"])
+                    continue
+                iid, fcid = parts[0], parts[2]
                 instruments.add(iid)
-                for rg in ngsfile.handle.header.to_dict()["RG"]:
-                    if rg["ID"] == read["read_group"]:
-                        if "PU" in rg:
-                            flowcells.add(rg["PU"])
-                        if "PM" in rg:
-                            instruments.add(rg["PM"])
-                continue
-            iid, fcid = parts[0], parts[2]
-            instruments.add(iid)
-            flowcells.add(fcid)
+                flowcells.add(fcid)
+        except KeyError:  # no RG tag is present
+            result = {
+                "File": ngsfilepath,
+                "Instrument": "unknown",
+                "Confidence": "no confidence",
+                "Basis": "no RG tag present",
+            }
+            writer.writerow(result)
+            outfile.flush()
+            continue
+
         if malformed_read_names:
             logger.warning(
                 "Encountered read names not in Illumina format. Recovery attempted."
