@@ -2,7 +2,6 @@ import logging
 import sys
 import os
 import csv
-import random
 
 from collections import defaultdict
 from pathlib import Path
@@ -34,7 +33,6 @@ def annotate_junctions(
     consider_unannotated_references_novel,
     junction_dir,
     disable_junction_files,
-    sample_rate=1,
 ):
     try:
         ngsfile = NGSFile(ngsfilepath)
@@ -50,7 +48,7 @@ def annotate_junctions(
             "complete_novel_spliced_reads": "N/A",
             "partial_novel_spliced_reads": "N/A",
         }
-        return result
+        return [result]
 
     if ngsfile.filetype != NGSFileType.BAM:
         raise RuntimeError(
@@ -99,11 +97,6 @@ def annotate_junctions(
             f"Found {len(events)} potential splice junctions. {len(found_introns) - len(events)} potential junctions too short."
         )
 
-        if sample_rate < 1:
-            n_samples = round(len(events) * sample_rate)
-            events = random.sample(events, n_samples)
-            logger.debug(f"Randomly sampled {n_samples} events.")
-
         if contig not in cache.exon_starts:
             logger.info(f"{contig} not found in GFF. All events marked `unannotated_reference`.")
             annotation = "unannotated_reference"
@@ -263,14 +256,14 @@ def annotate_junctions(
 def main(
     ngsfiles,
     gene_model_file,
-    outfile=sys.stdout,
-    min_intron=50,
-    min_mapq=30,
-    min_reads=2,
-    fuzzy_range=0,
-    consider_unannotated_references_novel=False,
-    junction_dir="./",
-    disable_junction_files=False,
+    outfile,
+    min_intron,
+    min_mapq,
+    min_reads,
+    fuzzy_range,
+    consider_unannotated_references_novel,
+    junction_dir,
+    disable_junction_files,
 ):
     logger.info("Arguments:")
     logger.info("  - Gene model file: {}".format(gene_model_file))
